datasets - MultiMolecule
Author: MultiMolecule
Description: Neural Networks for RNA, DNA, and Protein

跳转至

# datasets

`datasets` 提供了一系列广泛使用的数据集。

## 可用数据集

### 脱氧核糖核酸（DNA）

- GeneCode

### 核糖核酸（RNA）

- RNACentral
- Rfam
- bpRNA-1m

2024-06-25 15:24:27

#### Cookie Consent

We use cookies to recognize your repeated visits and preferences, as well as to measure the effectiveness of our documentation and whether users find what they're searching for. With your consent, you're helping us to make our documentation better. Please check out our Privacy Notice for more information.

- Google Analytics
- GitHub

管理设定